# From src/version.h:#define OCTAVE_API_VERSION
%global octave_api api-v48+

Name:           octave
Version:        3.6.2
Release:        1%{?dist}
Summary:        A high-level language for numerical computations
Epoch:          6
Group:          Applications/Engineering
License:        GPLv3+%if 0%{!?rcver:1}
Source0:        ftp://ftp.gnu.org/gnu/octave/octave-%{version}.tar.bz2
# RPM macros for helping to build Octave packages
Source1:        macros.octave
# https://savannah.gnu.org/bugs/index.php?32839
# Fix building packages from directories
Patch2:         octave-3.4.0-pkgbuilddir.patch
# Update gnulib to handle gets deprecation
Patch3:         octave-gets.patch
URL:            http://www.octave.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Provides:       octave(api) = %{octave_api}
Provides:       bundled(gnulib)

BuildRequires:  bison flex less tetex gcc-gfortran atlas-devel 
BuildRequires:  ncurses-devel zlib-devel hdf5-devel texinfo qhull-devel
BuildRequires:  readline-devel glibc-devel fftw-devel gperf ghostscript
BuildRequires:  curl-devel pcre-devel texinfo-tex arpack-devel libX11-devel
BuildRequires:  suitesparse-devel glpk-devel gnuplot 
BuildRequires:  GraphicsMagick-c++-devel fltk-devel ftgl-devel qrupdate-devel
BuildRequires:  tex(dvips)

Requires:        epstool gnuplot less info texinfo 
Requires:        hdf5 = %{_hdf5_version}
Requires(post):  info
Requires(preun): info


%description
GNU Octave is a high-level language, primarily intended for numerical
computations. It provides a convenient command line interface for
solving linear and nonlinear problems numerically, and for performing
other numerical experiments using a language that is mostly compatible
with Matlab. It may also be used as a batch-oriented language. Octave
has extensive tools for solving common numerical linear algebra
problems, finding the roots of nonlinear equations, integrating
ordinary functions, manipulating polynomials, and integrating ordinary
differential and differential-algebraic equations. It is easily
extensible and customizable via user-defined functions written in
Octave's own language, or using dynamically loaded modules written in
C++, C, Fortran, or other languages.


%package devel
Summary:        Development headers and files for Octave
Group:          Development/Libraries
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       readline-devel fftw-devel hdf5-devel zlib-devel
Requires:       atlas-devel gcc-c++ gcc-gfortran bison flex

%description devel
The octave-devel package contains files needed for developing
applications which use GNU Octave.

%prep
%setup -q -n %{name}-%{version}%{?rctag}
%patch2 -p1 -b .pkgbuilddir
%patch3 -p1 -b .gets

# Check permissions
find -name *.cc -exec chmod 644 {} \;

%build
%global enable64 no
export F77=gfortran
# TODO: arpack (and others?) appear to be bundled in libcruft.. 
#   --with-arpack is not an option anymore
#   gl2ps.c is bundled.  Anything else?
%configure CFLAGS=-O2 CXXFLAGS=-O2 --without-curl --disable-docs

# Check that octave_api is set correctly (autogenerated file)
make -C src version.h
if ! grep -q '^#define OCTAVE_API_VERSION "%{octave_api}"' src/version.h
then
  echo "octave_api variable in spec does not match src/version.h"
  exit 1
fi

# SMP make still not working in Octave 3.6.0
#make OCTAVE_RELEASE="Fedora %{version}-%{release}" %{?_smp_mflags}
make OCTAVE_RELEASE="CentOS %{version}%{?rctag}-%{release}"

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_infodir}/dir

# Make library links
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/octave/%{version}%{?rctag}" > %{buildroot}%{_sysconfdir}/ld.so.conf.d/octave-%{_arch}.conf

# Remove RPM_BUILD_ROOT from ls-R files
perl -pi -e "s,%{buildroot},," %{buildroot}%{_libdir}/%{name}/ls-R
perl -pi -e "s,%{buildroot},," %{buildroot}%{_datadir}/%{name}/ls-R
# Make sure ls-R exists
touch %{buildroot}%{_datadir}/%{name}/ls-R

# Create directories for add-on packages
HOST_TYPE=`%{buildroot}%{_bindir}/octave-config -p CANONICAL_HOST_TYPE`
mkdir -p %{buildroot}%{_libdir}/%{name}/site/oct/%{octave_api}/$HOST_TYPE
mkdir -p %{buildroot}%{_libdir}/%{name}/site/oct/$HOST_TYPE
mkdir -p %{buildroot}%{_datadir}/%{name}/packages
mkdir -p %{buildroot}%{_libdir}/%{name}/packages
touch %{buildroot}%{_datadir}/%{name}/octave_packages

# work-around broken pre-linking (bug 524493)
#install -d %{buildroot}%{_sysconfdir}/prelink.conf.d
#echo "-b %{_bindir}/octave-%{version}" > %{buildroot}%{_sysconfdir}/prelink.conf.d/octave.conf

# Fix multilib installs
for include in config defaults oct-conf
do
   mv %{buildroot}%{_includedir}/%{name}-%{version}%{?rctag}/%{name}/${include}.h \
      %{buildroot}%{_includedir}/%{name}-%{version}%{?rctag}/%{name}/${include}-%{__isa_bits}.h
   cat > %{buildroot}%{_includedir}/%{name}-%{version}%{?rctag}/%{name}/${include}.h <<EOF
#include <bits/wordsize.h>

#if __WORDSIZE == 32
#include "${include}-32.h"
#elif __WORDSIZE == 64
#include "${include}-64.h"
#else
#error "Unknown word size"
#endif
EOF
done
for script in octave-config-%{version}%{?rctag} mkoctfile-%{version}%{?rctag}
do
   mv %{buildroot}%{_bindir}/${script} %{buildroot}%{_libdir}/%{name}/%{version}%{?rctag}/${script}
   cat > %{buildroot}%{_bindir}/${script} <<EOF
#!/bin/bash
ARCH=\$(uname -m)

case \$ARCH in
x86_64 | ia64 | s390x) LIB_DIR=/usr/lib64
                       SECONDARY_LIB_DIR=/usr/lib
                       ;;
* )
                       LIB_DIR=/usr/lib
                       SECONDARY_LIB_DIR=/usr/lib64
                       ;;
esac

if [ ! -x \$LIB_DIR/%{name}/%{version}%{?rctag}/${script} ] ; then
  if [ ! -x \$SECONDARY_LIB_DIR/%{name}/%{version}%{?rctag}/${script} ] ; then
    echo "Error: \$LIB_DIR/%{name}/%{version}%{?rctag}/${script} not found"
    if [ -d \$SECONDARY_LIB_DIR ] ; then
      echo "   and \$SECONDARY_LIB_DIR/%{name}/%{version}%{?rctag}/${script} not found"
    fi
    exit 1
  fi
  LIB_DIR=\$SECONDARY_LIB_DIR
fi
exec \$LIB_DIR/%{name}/%{version}%{?rctag}/${script} "\$@"
EOF
   chmod +x %{buildroot}%{_bindir}/${script}
done

# rpm macros
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cp -p %SOURCE1 %{buildroot}%{_sysconfdir}/rpm/

%clean
rm -rf %{buildroot}

%post
/sbin/ldconfig
/sbin/install-info --info-dir=%{_infodir} --section="Programming" \
        %{_infodir}/octave.info || :

%preun
if [ "$1" = "0" ]; then
   /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/octave.info || :
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS BUGS ChangeLog COPYING NEWS README
# FIXME: Create an -emacs package that has the emacs addon
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/octave-*.conf
%{_bindir}/octave*
%{_libdir}/octave/
%{_libexecdir}/octave/
#%{_mandir}/man1/octave*.1.*
#%{_infodir}/liboctave.info*
#%{_infodir}/octave.info*
#%{_infodir}/OctaveFAQ.info*
# octave_packages is %ghost, so need to list everything else separately
%dir %{_datadir}/octave
%{_datadir}/octave/%{version}%{?rctag}/
%{_datadir}/octave/ls-R
%ghost %{_datadir}/octave/octave_packages
%{_datadir}/octave/packages/
%{_datadir}/octave/site/
#%{_sysconfdir}/prelink.conf.d/octave.conf

%files devel
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/rpm/macros.octave
%{_bindir}/mkoctfile
%{_bindir}/mkoctfile-%{version}%{?rctag}
%{_includedir}/octave-%{version}%{?rctag}/
#%{_mandir}/man1/mkoctfile.1.*
